==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/ComponentContainer.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Nov 30, 2009
 * Author: T. Rekawek <newton@mat.uni.torun.pl>
 */

package pl.edu.icm.unicore.uvos.server;

import java.util.Timer;

import org.picocontainer.DefaultPicoContainer;
import org.picocontainer.MutablePicoContainer;
import org.picocontainer.Parameter;
import org.picocontainer.PicoContainer;
import org.picocontainer.behaviors.Caching;
import org.picocontainer.parameters.ConstantParameter;

import pl.edu.icm.unicore.uvos.db.DB;
import pl.edu.icm.unicore.uvos.db.DBApps;
import pl.edu.icm.unicore.uvos.db.DBAttributeTypes;
import pl.edu.icm.unicore.uvos.db.DBAuthz;
import pl.edu.icm.unicore.uvos.db.DBEntities;
import pl.edu.icm.unicore.uvos.db.DBEntitiesCache;
import pl.edu.icm.unicore.uvos.db.DBGroupResolver;
import pl.edu.icm.unicore.uvos.db.DBGroups;
import pl.edu.icm.unicore.uvos.db.DBIdentityTypes;
import pl.edu.icm.unicore.uvos.db.DBLock;
import pl.edu.icm.unicore.uvos.db.DBNotification;
import pl.edu.icm.unicore.uvos.engine.ManagementModule;
import pl.edu.icm.unicore.uvos.engine.PersistentIdManager;
import pl.edu.icm.unicore.uvos.engine.QueryHistoryModule;
import pl.edu.icm.unicore.uvos.engine.QueryModule;
import pl.edu.icm.unicore.uvos.engine.VOApplicationModule;
import pl.edu.icm.unicore.uvos.engine.VOAuthorizationModule;
import pl.edu.icm.unicore.uvos.mail.MailSender;
import pl.edu.icm.unicore.uvos.registration.ClientSecurityConfiguration;
import pl.edu.icm.unicore.uvos.saml.SAMLConfiguration;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.server.saml.AttributeConverter;
import pl.edu.icm.unicore.uvos.server.saml.AttributeFilterImpl;
import pl.edu.icm.unicore.uvos.server.saml.ReplayAttackChecker;
import pl.edu.icm.unicore.uvos.server.saml.SAMLAuthImpl;
import pl.edu.icm.unicore.uvos.server.saml.SAMLNameIdMappingImpl;
import pl.edu.icm.unicore.uvos.server.saml.SAMLQueryImpl;
import pl.edu.icm.unicore.uvos.server.saml.SAMLX509QueryProfile;
import pl.edu.icm.unicore.uvos.util.AttributeTypesLoader;
import pl.edu.icm.unicore.uvos.util.Configuration;

/**
 * PicoContainer-based UVOS component container.
 * @author T. Rekawek
 */
public class ComponentContainer
{
	private MutablePicoContainer mPico;
	
	public ComponentContainer()
	{
		mPico = new DefaultPicoContainer();
		addComponents(VOServer.CONFIGURATION_FILE);
	}
	
	public ComponentContainer(String configFile)
	{
		mPico = new DefaultPicoContainer(new Caching());
		addComponents(configFile);
	}
	
	private void addComponents(String configFile)
	{
		// DB classes
		mPico.addComponent(DB.class);
		mPico.addComponent(DBApps.class);
		mPico.addComponent(DBAttributeTypes.class);
		mPico.addComponent(DBAuthz.class);
		mPico.addComponent(DBEntities.class);
		mPico.addComponent(DBEntitiesCache.class);
		mPico.addComponent(DBGroupResolver.class);
		mPico.addComponent(DBGroups.class);
		mPico.addComponent(DBIdentityTypes.class);
		mPico.addComponent(DBLock.class);
		mPico.addComponent(DBNotification.class);
		
		// engine classes
		mPico.addComponent(ManagementModule.class);
		mPico.addComponent(PersistentIdManager.class);
		mPico.addComponent(QueryHistoryModule.class);
		mPico.addComponent(QueryModule.class);
		mPico.addComponent(VOApplicationModule.class);
		mPico.addComponent(VOAuthorizationModule.class);
		
		// mail classes
		mPico.addComponent(MailSender.class);
		
		// registration classes
		mPico.addComponent(ClientSecurityConfiguration.class);
		
		// server classes
		mPico.addComponent(CryptoDataProviderImpl.class);
		mPico.addComponent(VOServer.class);
		mPico.addComponent(WSApplicationsImpl.class);
		mPico.addComponent(WSAuthZImpl.class);
		mPico.addComponent(WSManagementImpl.class);
		mPico.addComponent(WSQueryHistoryImpl.class);
		mPico.addComponent(WSQueryImpl.class);
		mPico.addComponent(AttributeFilterImpl.class);
		mPico.addComponent(WSGLUEInfoProviderImpl.class);
		
		// authenticator
		mPico.addComponent(Authenticator.class);
		
		// saml classes
		mPico.addComponent(AttributeConverter.class);
		mPico.addComponent(ReplayAttackChecker.class);
		mPico.addComponent(SAMLAuthImpl.class);
		mPico.addComponent(SAMLConfiguration.class);
		mPico.addComponent(SAMLNameIdMappingImpl.class);
		mPico.addComponent(SAMLQueryImpl.class);
		mPico.addComponent(SAMLX509QueryProfile.class);
		
		// util classes
		mPico.addComponent(new Timer("UVOS server timer", true));
		mPico.addComponent(AttributeTypesLoader.class);
		mPico.addComponent(Configuration.class, Configuration.class,
				new Parameter[] { new ConstantParameter(configFile) } );

	}
	
	public <T> T getComponent(Class<T> clazz)
	{
		return mPico.getComponent(clazz);
	}
	
	public PicoContainer getContainer()
	{
		return mPico;
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/ComponentContainer.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Nov 30, 2009
 * Author: T. Rekawek <newton@mat.uni.torun.pl>
 */

package pl.edu.icm.unicore.uvos.server;

import org.picocontainer.DefaultPicoContainer;
import org.picocontainer.MutablePicoContainer;
import org.picocontainer.Parameter;
import org.picocontainer.PicoContainer;
import org.picocontainer.behaviors.Caching;
import org.picocontainer.parameters.ConstantParameter;

import pl.edu.icm.unicore.uvos.db.DB;
import pl.edu.icm.unicore.uvos.db.DBApps;
import pl.edu.icm.unicore.uvos.db.DBAttributeTypes;
import pl.edu.icm.unicore.uvos.db.DBAuthz;
import pl.edu.icm.unicore.uvos.db.DBEntities;
import pl.edu.icm.unicore.uvos.db.DBEntitiesCache;
import pl.edu.icm.unicore.uvos.db.DBGroupResolver;
import pl.edu.icm.unicore.uvos.db.DBGroups;
import pl.edu.icm.unicore.uvos.db.DBIdentityTypes;
import pl.edu.icm.unicore.uvos.db.DBLock;
import pl.edu.icm.unicore.uvos.db.DBNotification;
import pl.edu.icm.unicore.uvos.engine.ManagementModule;
import pl.edu.icm.unicore.uvos.engine.PersistentIdManager;
import pl.edu.icm.unicore.uvos.engine.QueryHistoryModule;
import pl.edu.icm.unicore.uvos.engine.QueryModule;
import pl.edu.icm.unicore.uvos.engine.VOApplicationModule;
import pl.edu.icm.unicore.uvos.engine.VOAuthorizationModule;
import pl.edu.icm.unicore.uvos.mail.MailSender;
import pl.edu.icm.unicore.uvos.registration.EMIRHandler;
import pl.edu.icm.unicore.uvos.saml.SAMLConfiguration;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.server.saml.AttributeConverter;
import pl.edu.icm.unicore.uvos.server.saml.AttributeFilterImpl;
import pl.edu.icm.unicore.uvos.server.saml.ReplayAttackChecker;
import pl.edu.icm.unicore.uvos.server.saml.SAMLAuthImpl;
import pl.edu.icm.unicore.uvos.server.saml.SAMLNameIdMappingImpl;
import pl.edu.icm.unicore.uvos.server.saml.SAMLQueryImpl;
import pl.edu.icm.unicore.uvos.server.saml.SAMLX509QueryProfile;
import pl.edu.icm.unicore.uvos.util.AttributeTypesLoader;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;
import pl.edu.icm.unicore.uvos.util.GLUEInfoProvider;
import pl.edu.icm.unicore.uvos.util.ThreadScheduler;

/**
 * PicoContainer-based UVOS component container.
 * @author T. Rekawek
 */
public class ComponentContainer
{
	private MutablePicoContainer mPico;
	
	public ComponentContainer()
	{
		mPico = new DefaultPicoContainer();
		addComponents(VOServer.CONFIGURATION_FILE);
	}
	
	public ComponentContainer(String configFile)
	{
		mPico = new DefaultPicoContainer(new Caching());
		addComponents(configFile);
	}
	
	private void addComponents(String configFile)
	{		
		// DB classes
		mPico.addComponent(DB.class);
		mPico.addComponent(DBApps.class);
		mPico.addComponent(DBAttributeTypes.class);
		mPico.addComponent(DBAuthz.class);
		mPico.addComponent(DBEntities.class);
		mPico.addComponent(DBEntitiesCache.class);
		mPico.addComponent(DBGroupResolver.class);
		mPico.addComponent(DBGroups.class);
		mPico.addComponent(DBIdentityTypes.class);
		mPico.addComponent(DBLock.class);
		mPico.addComponent(DBNotification.class);
		
		// engine classes
		mPico.addComponent(ManagementModule.class);
		mPico.addComponent(PersistentIdManager.class);
		mPico.addComponent(QueryHistoryModule.class);
		mPico.addComponent(QueryModule.class);
		mPico.addComponent(VOApplicationModule.class);
		mPico.addComponent(VOAuthorizationModule.class);
		
		// mail classes
		mPico.addComponent(MailSender.class);
		
		// server classes
		mPico.addComponent(IssuerIdentityProviderImpl.class);
		mPico.addComponent(VOServer.class);
		mPico.addComponent(WSApplicationsImpl.class);
		mPico.addComponent(WSAuthZImpl.class);
		mPico.addComponent(WSManagementImpl.class);
		mPico.addComponent(WSQueryHistoryImpl.class);
		mPico.addComponent(WSQueryImpl.class);
		mPico.addComponent(AttributeFilterImpl.class);
		mPico.addComponent(WSGLUEInfoProviderImpl.class);
		
		// authenticator
		mPico.addComponent(Authenticator.class);
		
		// saml classes
		mPico.addComponent(AttributeConverter.class);
		mPico.addComponent(ReplayAttackChecker.class);
		mPico.addComponent(SAMLAuthImpl.class);
		mPico.addComponent(SAMLConfiguration.class);
		mPico.addComponent(SAMLNameIdMappingImpl.class);
		mPico.addComponent(SAMLQueryImpl.class);
		mPico.addComponent(SAMLX509QueryProfile.class);
		
		// util classes
		mPico.addComponent(AttributeTypesLoader.class);
		mPico.addComponent(UVOSServerProperties.class, UVOSServerProperties.class,
				new Parameter[] { new ConstantParameter(configFile) } );
		mPico.addComponent(ThreadScheduler.class);
		mPico.addComponent(GLUEInfoProvider.class);
		mPico.addComponent(EMIRHandler.class);
	}
	
	public <T> T getComponent(Class<T> clazz)
	{
		return mPico.getComponent(clazz);
	}
	
	public PicoContainer getContainer()
	{
		return mPico;
	}
}
